@@ -316,7 +316,7 @@ static char* messages[] =
   "\"Mail Routing and the Domain System\" by Craig Partridge.",
   "\"The Theory and Practice of Oligarchical Collectivism\" by Emmanuel Goldstein.", 
   "\"201 Kitten Verbs, Fully Conjugated\".  You look for \"find\".",
-  "A card sharp sits here, practicing his Faro shuffle.  He ignores you.",
+  "A card shark sits here, practicing his Faro shuffle.  He ignores you.",
   "A copy of DeCSS.  They're a dime a dozen these days.",
   "A demonic voice proclaims \"There is no kitten, only Zuul\".  You flee.",
   "A lotus.  You make an interesting pair.",
@@ -345,8 +345,7 @@ static char* messages[] =
   "You hit the non-kitten item.  The non-kitten item fails to yowl.",
   "You suddenly yearn for your distant homeland.",
   "You've found the snows of yesteryear!  So that's where they all went to.",
-  "Approaching.  One car.  J.  Followed by.  Two car.  M, M.  In five.  Minutes.",
-  
+  "Approaching.  One car.  J.  Followed by.  Two car.  M, M.  In five. Minutes.",
   "Free Jon Johansen!",
   "Free Dmitry Sklyarov!",
   "One person shouts \"What do we want?\" The crowd answers \"Free Dmitry!\"",
@@ -360,8 +359,63 @@ static char* messages[] =
   "If it's one thing, it's not another.",
   "If it's not one thing, it's another.",
   "A caboodle.",
-  "A grin."
-
-
+  "A grin.",
+  "A hedgehog.  It looks like it knows something important.",
+  "You've found... Oh wait, that's just a cat.",
+  "Robot should not be touching that.",
+  "Air Guitar!!!  NA na NA na!!",
+  "An aromatherapy candle burns with healing light.",
+  "You find a bright shiny penny.",
+  "It's a free Jon Johansen!",
+  "It's a free Dmitry Sklyarov!",
+  "The rothe hits!  The rothe hits!",
+  "It's an Internet chain letter about sodium laureth sulfate.",
+  "Ed Witten sits here, pondering string theory.",
+  "Something is written here in the dust.  You read: \"rJbotf ndQkttten\".",
+  "We wish you a merry kitten, and a happy New Year!",
+  "Run away!  Run away!",
+  "You can see right through this copy of Brin\'s \"Transparent Society\".",
+  "This copy of \"Steal This Book\" has been stolen from a bookstore.",
+  "It's Roya Naini.",
+  "This kit is the fourteenth in a series of kits named with Roman letters.",
+  "This is the tenth key you've found so far.",
+  "You find a fraud scheme in which loans are used as security for other loans.",
+  "It's the phrase \"and her\", written in ancient Greek.",
+  "It's the author of \"Randomness and Mathematical Proof\".",
+  "It's the crusty exoskeleton of an arthropod!",
+  "It's Emporer Shaddam the 4th's planet!",
+  "It's the triangle leg adjacent to an angle divided by the leg opposite it.",
+  "It's a bottle of nail polish remover.",
+  "You found netkit! Way to go, robot!",
+  "It's the ASCII Floating Head of Seth David Schoen!",
+  "A frosted pink party-cake, half eaten.",
+  "A bitchin' homemade tesla coil.",
+  "Conan O'Brian, sans jawbone.",
+  "It's either a mirror, or another soulless kitten-seeking robot.",
+  "Preoccupation with finding kitten prevents you from investigating further.",
+  "Fonzie sits here, mumbling incoherently about a shark and a pair of waterskis.",
+  "The ghost of your dance instructor, his face a paper-white mask of evil.",
+  "A bag of groceries taken off the shelf before the expiration date.",
+  "A book: Feng Shui, Zen: the art of randomly arranging items that are not kitten.",
+  "This might be the fountain of youth, but you'll never know.",
+  "Tigerbot Hesh.",
+  "Stimutacs.",
+  "A canister of pressurized whipped cream, sans whipped cream.",
+  "The non-kitten item bites!",
+  "A chain hanging from two posts reminds you of the Gateway Arch.",
+  "A mathematician calculates the halting probability of a Turing machine.",
+  "A number of short theatrical productions are indexed 1, 2, 3, ... n.",
+  "A technical university in Australia.",
+  "It is -- I just feel something wonderful is about to happen.",
+  "It's a Cat 5 cable.",
+  "It's a U.S. president.",
+  "It's a piece of cloth used to cover a stage in between performances.",
+  "The ionosphere seems charged with meaning.",
+  "This tomography is like, hella axial, man!",
+  "It's your favorite game -- robotfindscatan!",
+  "Just a man selling an albatross.",
+  "The intermission from a 1930s silent movie.",
+  "It's an inverted billiard ball!",
+  "The spectre of Sherlock Holmes wills you onwards.",
 
 };
